@@ -24,20 +24,21 @@
 import ast
 import platform
 import time
-import datetime
 import logging
 from logging.config import fileConfig
-import os
 from threading import Lock
 import traceback
 import sys
 
+import os
 from gevent import monkey
 import gevent
 
+import datetime
+
 
 logger = logging.getLogger("SolBase")
-lifecyclelogger = logging.getLogger("LifeCycle")
+lifecyclelogger = logging.getLogger("lifecycle")
 
 
 class SolBase(object):
@@ -45,32 +46,30 @@ class SolBase(object):
     Base utilities & helpers.
     """
 
-    #===============================
+    # ===============================
     # STATIC STUFF
     #===============================
 
     # Component name (mainly for rsyslog)
-    _compoName = "CompoNotSet"
+    _compo_name = "CompoNotSet"
 
     # Global init stuff
-    _voodooInitialized = False
-    _voodooLock = Lock()
+    _voodoo_initialized = False
+    _voodoo_lock = Lock()
 
     # Logging stuff
-    _loggingInitialized = False
-    _loggingLock = Lock()
+    _logging_initialized = False
+    _logging_lock = Lock()
 
     # Fork stuff
-    _masterProcess = True
-
-
+    _master_process = True
 
     #===============================
     # DATE & MS
     #===============================
 
     @classmethod
-    def msCurrent(cls):
+    def mscurrent(cls):
         """
         Return current millis since epoc
         :return int
@@ -79,61 +78,60 @@ class SolBase(object):
         return time.time() * 1000.0
 
     @classmethod
-    def msDiff(cls, msStart, msEnd=None):
+    def msdiff(cls, ms_start, ms_end=None):
         """
         Get difference in millis between current millis and provided millis.
-        :param msStart: Start millis
-        :type msStart: float
-        :param msEnd: End millis (will use current if not provided)
-        :type msEnd: float
+        :param ms_start: Start millis
+        :type ms_start: float
+        :param ms_end: End millis (will use current if not provided)
+        :type ms_end: float
         :return float
         :rtype float
         """
 
-        if msEnd:
-            return msEnd - msStart
+        if ms_end:
+            return ms_end - ms_start
         else:
-            return cls.msCurrent() - msStart
+            return cls.mscurrent() - ms_start
 
     @classmethod
-    def dateCurrent(cls, eraseMode=0):
+    def datecurrent(cls, erase_mode=0):
         """
         Return current date (UTC)
-        :param eraseMode: Erase mode (0=nothing, 1=remove microseconds but keep millis, 2=remove millis completely)
+        :param erase_mode: Erase mode (0=nothing, 1=remove microseconds but keep millis, 2=remove millis completely)
         :return datetime
         :rtype datetime
         """
 
-        if eraseMode == 0:
+        if erase_mode == 0:
             return datetime.datetime.utcnow()
-        elif eraseMode == 1:
+        elif erase_mode == 1:
             # Force precision loss (keep millis, kick micro)
             dt = datetime.datetime.utcnow()
             return dt.replace(microsecond=(dt.microsecond * 0.001) * 1000)
-        elif eraseMode == 2:
+        elif erase_mode == 2:
             return datetime.datetime.utcnow().replace(microsecond=0)
 
     @classmethod
-    def dateDiff(cls, dtStart, dtEnd=None):
+    def datediff(cls, dt_start, dt_end=None):
         """
         Get difference in millis between two datetime
-        :param dtStart: Start datetime
-        :type dtStart: datetime
-        :param dtEnd: End datetime (will use current utc if not provided)
-        :type dtEnd: datetime
+        :param dt_start: Start datetime
+        :type dt_start: datetime
+        :param dt_end: End datetime (will use current utc if not provided)
+        :type dt_end: datetime
         :return float
         :rtype float
         """
 
         # Get delta
-        if dtEnd:
+        if dt_end:
             # noinspection PyUnresolvedReferences
-            delta = dtEnd - dtStart
+            delta = dt_end - dt_start
         else:
             # noinspection PyTypeChecker
-            delta = cls.dateCurrent() - dtStart
+            delta = cls.datecurrent() - dt_start
 
-        # From : http://stackoverflow.com/questions/4898687/python-parsing-timestamps-and-calculating-time-differences-in-milliseconds
         return ((delta.days * 86400 + delta.seconds) * 1000) + (delta.microseconds * 0.001)
 
     #===============================
@@ -141,29 +139,29 @@ class SolBase(object):
     #===============================
 
     @classmethod
-    def setCompoName(cls, compoName):
+    def set_compo_name(cls, compo_name):
         """
         Set the component name. Useful for rsyslog.
-        :param compoName: The component name or None. If None, method do nothing.
-        :type compoName: str,None
+        :param compo_name: The component name or None. If None, method do nothing.
+        :type compo_name: str,None
         """
 
-        if compoName:
-            cls._compoName = compoName
-            lifecyclelogger.info("compoName now set to=%s", cls._compoName)
+        if compo_name:
+            cls._compo_name = compo_name
+            lifecyclelogger.info("compo_name now set to=%s", cls._compo_name)
 
     @classmethod
-    def getCompoName(cls):
+    def get_compo_name(cls):
         """
         Get current component name.
         :return str
         :rtype str
         """
 
-        return cls._compoName
+        return cls._compo_name
 
     @classmethod
-    def getMachineName(cls):
+    def get_machine_name(cls):
         """
         Get machine name
         :return: Machine name
@@ -177,59 +175,59 @@ class SolBase(object):
     #===============================
 
     @classmethod
-    def sleep(cls, sleepMs):
+    def sleep(cls, sleep_ms):
         """
         Sleep for specified ms.
         Also used as gevent context switch in code, since it rely on gevent.sleep.
-        :param sleepMs: Millis to sleep.
-        :type sleepMs: int
+        :param sleep_ms: Millis to sleep.
+        :type sleep_ms: int
         :return Nothing.
         """
-        gevent.sleep(sleepMs * 0.001)
+        gevent.sleep(sleep_ms * 0.001)
 
     #===============================
     # EXCEPTION HELPER
     #===============================
 
     @classmethod
-    def exToStr(cls, e, maxLevel=10, maxPathLevel=5):
+    def extostr(cls, e, max_level=10, max_path_level=5):
         """
         Format an exception.
         :param e: Any exception instance.
         :type e: Exception
-        :param maxLevel: Maximum call stack level (default 10)
-        :type maxLevel: int
-        :param maxPathLevel: Maximum path level (default 5)
-        :type maxPathLevel: int
+        :param max_level: Maximum call stack level (default 10)
+        :type max_level: int
+        :param max_path_level: Maximum path level (default 5)
+        :type max_path_level: int
         :return The exception readable string
         :rtype str
         """
 
         # Go
-        listFrame = None
+        list_frame = None
         try:
-            outBuffer = ""
+            out_buffer = ""
 
             # Class type
-            outBuffer += "e.cls:[{0}]".format(e.__class__.__name__)
+            out_buffer += "e.cls:[{0}]".format(e.__class__.__name__)
 
             # To string
             try:
-                exBuf = str(e)
+                ex_buf = str(e)
             except UnicodeEncodeError:
-                exBuf = str(repr(unicode(e)))
+                ex_buf = str(repr(unicode(e)))
             except Exception as e:
                 logger.error("Exception, e=%s", e)
                 raise
-            outBuffer += ", e.str:[{0}]".format(exBuf)
+            out_buffer += ", e.str:[{0}]".format(ex_buf)
 
             # Traceback
             si = sys.exc_info()
 
             # Raw frame
             # tuple : (file, lineno, method, code)
-            rawFrame = traceback.extract_tb(si[2])
-            rawFrame.reverse()
+            raw_frame = traceback.extract_tb(si[2])
+            raw_frame.reverse()
 
             # Go to last tb_next
             last_tb_next = None
@@ -239,59 +237,59 @@ class SolBase(object):
                 cur_tb = cur_tb.tb_next
 
             # Skip frame up to current raw frame count
-            listFrame = list()
-            curCount = -1
-            skipCount = len(rawFrame)
-            curFrame = last_tb_next.tb_frame
-            while curFrame:
-                curCount += 1
-                if curCount < skipCount:
-                    curFrame = curFrame.f_back
+            list_frame = list()
+            cur_count = -1
+            skip_count = len(raw_frame)
+            cur_frame = last_tb_next.tb_frame
+            while cur_frame:
+                cur_count += 1
+                if cur_count < skip_count:
+                    cur_frame = cur_frame.f_back
                 else:
                     # Need : tuple : (file, lineno, method, code)
-                    rawFrame.append((curFrame.f_code.co_filename, curFrame.f_lineno, curFrame.f_code.co_name, ""))
-                    curFrame = curFrame.f_back
+                    raw_frame.append((cur_frame.f_code.co_filename, cur_frame.f_lineno, cur_frame.f_code.co_name, ""))
+                    cur_frame = cur_frame.f_back
 
             # Build it
-            curIdx = 0
-            outBuffer += ", e.cs=["
-            for tu in rawFrame:
+            cur_idx = 0
+            out_buffer += ", e.cs=["
+            for tu in raw_frame:
                 line = str(tu[1])
-                curfile = tu[0]
+                cur_file = tu[0]
                 method = tu[2]
 
                 # Handle max path level
-                arToken = curfile.rsplit(os.sep, maxPathLevel)
-                if len(arToken) > maxPathLevel:
+                ar_token = cur_file.rsplit(os.sep, max_path_level)
+                if len(ar_token) > max_path_level:
                     # Remove head
-                    arToken.pop(0)
+                    ar_token.pop(0)
                     # Join
-                    curfile = "..." + os.sep.join(arToken)
+                    cur_file = "..." + os.sep.join(ar_token)
 
                 # Format
-                outBuffer += "in:{0}#{1}@{2} ".format(method, curfile, line)
+                out_buffer += "in:{0}#{1}@{2} ".format(method, cur_file, line)
 
                 # Loop
-                curIdx += 1
-                if curIdx >= maxLevel:
-                    outBuffer += "..."
+                cur_idx += 1
+                if cur_idx >= max_level:
+                    out_buffer += "..."
                     break
 
             # Close
-            outBuffer += "]"
+            out_buffer += "]"
 
             # Ok
-            return outBuffer
+            return out_buffer
         finally:
-            if listFrame:
-                del listFrame
+            if list_frame:
+                del list_frame
 
     #===============================
     # VOODOO INIT
     #===============================
 
     @classmethod
-    def voodooInit(cls, aggressive=True):
+    def voodoo_init(cls, aggressive=True):
         """
         Global initialization, to call asap.
         Apply gevent stuff & default logging configuration.
@@ -301,13 +299,13 @@ class SolBase(object):
         """
 
         # Check
-        if cls._voodooInitialized:
+        if cls._voodoo_initialized:
             return
 
         # Lock
-        with cls._voodooLock:
+        with cls._voodoo_lock:
             # Re-check
-            if cls._voodooInitialized:
+            if cls._voodoo_initialized:
                 return
 
             # Fire the voodoo magic :)
@@ -317,108 +315,110 @@ class SolBase(object):
 
             # Initialize log level to INFO
             lifecyclelogger.info("Voodoo : logging : entering")
-            cls.loggingInit()
+            cls.logging_init()
             lifecyclelogger.info("Voodoo : logging : done")
 
             # Done
-            cls._voodooInitialized = True
+            cls._voodoo_initialized = True
 
     #===============================
     # LOGGING
     #===============================
 
     @classmethod
-    def loggingInit(cls, logLevel="INFO", forceReset=False, logCallback=None, logToFile=None, logToSyslog=True):
+    def logging_init(cls, log_level="INFO", force_reset=False, log_callback=None, log_to_file=None, log_to_syslog=True):
         """
         Initialize logging sub system with default settings (console, pre-formatted output)
-        :param logLevel: The log level to set. Any value in "DEBUG", "INFO", "WARN", "ERROR", "CRITICAL"
-        :type logLevel: str
-        :param forceReset: If true, logging system is reset.
-        :type forceReset: bool
-        :param logToFile: If specified, log to file
-        :type logToFile: str
-        :pram logToSyslog: If specified, log to syslog
-        :type logToSyslog: bool
-        :param logCallback: Callback for unittest
+        :param log_level: The log level to set. Any value in "DEBUG", "INFO", "WARN", "ERROR", "CRITICAL"
+        :type log_level: str
+        :param force_reset: If true, logging system is reset.
+        :type force_reset: bool
+        :param log_to_file: If specified, log to file
+        :type log_to_file: str,None
+        :pram log_to_syslog: If specified, log to syslog
+        :type log_to_syslog: bool
+        :param log_callback: Callback for unittest
         :return Nothing.
         """
 
-        if cls._loggingInitialized == True and forceReset == False:
+        if cls._logging_initialized and not force_reset:
             return
 
-        with cls._loggingLock:
-            if cls._loggingInitialized == True and forceReset == False:
+        with cls._logging_lock:
+            if cls._logging_initialized and not force_reset:
                 return
 
             # Default
-            logging.basicConfig(level=logLevel)
+            logging.basicConfig(level=log_level)
 
             # Formatter
             f = logging.Formatter(
-                "%(asctime)s | %(levelname)s | %(module)s@%(funcName)s@%(lineno)d | %(message)s | %(thread)d:%(threadName)s | %(process)d:%(processName)s")
+                "%(asctime)s | %(levelname)s | %(module)s@%(funcName)s@%(lineno)d |"
+                " %(message)s | %(thread)d:%(threadName)s | %(process)d:%(processName)s")
 
             # Console handler
             c = logging.StreamHandler(sys.stdout)
-            c.setLevel(logging.getLevelName(logLevel))
+            c.setLevel(logging.getLevelName(log_level))
             c.setFormatter(f)
 
             # File handler to /tmp
-            cf=None
-            if logToFile:
-                cf = logging.FileHandler(logToFile)
-                cf.setLevel(logging.getLevelName(logLevel))
+            cf = None
+            if log_to_file:
+                cf = logging.FileHandler(log_to_file)
+                cf.setLevel(logging.getLevelName(log_level))
                 cf.setFormatter(f)
 
             # Syslog handler
-            if logToSyslog:
+            syslog = None
+            if log_to_syslog:
                 try:
                     from pythonsol.SysLogger import SysLogger
 
-                    syslog = SysLogger(logCallback=logCallback)
-                    syslog.setLevel(logging.getLevelName(logLevel))
+                    syslog = SysLogger(log_callback=log_callback)
+                    syslog.setLevel(logging.getLevelName(log_level))
                     syslog.setFormatter(f)
                 except Exception as e:
-                    raise Exception("Unable to import SysLogger, e=%s", SolBase.exToStr(e))
+                    raise Exception("Unable to import SysLogger, e=%s", SolBase.extostr(e))
 
             # Initialize
             root = logging.getLogger()
-            root.setLevel(logging.getLevelName(logLevel))
+            root.setLevel(logging.getLevelName(log_level))
             root.handlers = []
             root.addHandler(c)
-            if logToFile:
+            if log_to_file:
                 root.addHandler(cf)
-            if logToSyslog:
+            if log_to_syslog:
                 root.addHandler(syslog)
 
-
             # Done
-            cls._loggingInitialized = True
-            lifecyclelogger.info("Logging : initialized from memory, logLevel=%s, forceReset=%s", logLevel, forceReset)
+            cls._logging_initialized = True
+            lifecyclelogger.info("Logging : initialized from memory, log_level=%s, force_reset=%s", log_level,
+                                 force_reset)
 
     @classmethod
-    def loggingInitFomFile(cls, configFileName, forceReset=False):
+    def logging_initfromfile(cls, config_file_name, force_reset=False):
         """
         Initialize logging system from a configuration file, with optional reset.
-        :param configFileName: Configuration file name
-        :type configFileName: str
-        :param forceReset: If true, logging system is reset.
-        :type forceReset: bool
+        :param config_file_name: Configuration file name
+        :type config_file_name: str
+        :param force_reset: If true, logging system is reset.
+        :type force_reset: bool
         :return Nothing.
         """
 
-        if cls._loggingInitialized == True and forceReset == False:
+        if cls._logging_initialized and not force_reset:
             return
 
-        with cls._loggingLock:
-            if cls._loggingInitialized == True and forceReset == False:
+        with cls._logging_lock:
+            if cls._logging_initialized and not force_reset:
                 return
 
             try:
-                logger.debug("Logging : configFileName=%s", configFileName)
-                fileConfig(configFileName, None, False)
-                lifecyclelogger.info("Logging : initialized from file, configFileName=%s", configFileName)
+                logger.debug("Logging : config_file_name=%s", config_file_name)
+                fileConfig(config_file_name, None, False)
+                lifecyclelogger.info("Logging : initialized from file, config_file_name=%s", config_file_name)
             except Exception as e:
-                logger.error("Exception, e=%s", cls.exToStr(e))
+                logger.error("Exception, e=%s", cls.extostr(e))
                 raise
 
     #===============================
@@ -426,64 +426,64 @@ class SolBase(object):
     #===============================
 
     @classmethod
-    def getMasterProcess(cls):
+    def get_master_process(cls):
         """
         Return True if we are the master process, False otherwise.
         :return bool
         :rtype bool
         """
-        return cls._masterProcess
+        return cls._master_process
 
     @classmethod
-    def setMasterProcess(cls, isMaster):
+    def set_master_process(cls, b):
         """
         Set is we are a fork master or not
-        :param isMaster: True if we are master process, False if we are a child process.
-        :type isMaster: bool
+        :param b: True if we are master process, False if we are a child process.
+        :type b: bool
         :return Nothing
         """
 
-        logger.info("Switching _masterProcess to %s", isMaster)
-        cls._masterProcess = isMaster
+        logger.info("Switching _masterProcess to %s", b)
+        cls._master_process = b
 
     #===============================
     # BINARY STUFF
     #===============================
 
     @classmethod
-    def binaryToUnicode(cls, binBuf, encoding="utf-8"):
+    def binary_to_unicode(cls, bin_buf, encoding="utf-8"):
         """
         Binary buffer to unicode, using the specified encoding
-        :param binBuf: Binary buffer
-        :type binBuf: str
+        :param bin_buf: Binary buffer
+        :type bin_buf: str
         :param encoding: Encoding to use
         :type encoding: str
         :return unicode
         :rtype unicode
         """
 
-        return unicode(binBuf, encoding)
+        return unicode(bin_buf, encoding)
 
     @classmethod
-    def unicodeToBinary(cls, unicodeBuf, encoding="utf-8"):
+    def unicode_to_binary(cls, unicode_buf, encoding="utf-8"):
         """
         Unicode to binary buffer, using the specified encoding
-        :param unicodeBuf: String to convert.
-        :type unicodeBuf: unicode
+        :param unicode_buf: String to convert.
+        :type unicode_buf: unicode
         :param encoding: Encoding to use.
         :type encoding: str
         :return str
         :rtype str
         """
 
-        return unicodeBuf.encode(encoding)
+        return unicode_buf.encode(encoding)
 
     #===============================
     # CONVERSIONS
     #===============================
 
     @classmethod
-    def toInt(cls, v):
+    def to_int(cls, v):
         """
         Convert to int
         :param v: int,str
@@ -498,7 +498,7 @@ class SolBase(object):
             return int(v)
 
     @classmethod
-    def toLong(cls, v):
+    def to_long(cls, v):
         """
         Convert to long
         :param v: long,str
@@ -513,7 +513,7 @@ class SolBase(object):
             return long(v)
 
     @classmethod
-    def toBool(cls, v):
+    def to_bool(cls, v):
         """
         Convert to bool
         :param v: bool,str
@@ -528,20 +528,20 @@ class SolBase(object):
             return ast.literal_eval(v)
 
     @classmethod
-    def getClassName(cls, myInstance):
+    def get_classname(cls, my_instance):
         """
-        Return the class name of myInstance, or "Instance.None".
+        Return the class name of my_instance, or "Instance.None".
         :param cls: Our class.
-        :param myInstance: Instance to use.
-        :return: Return the class name of myInstance, or "Instance.None" in case of error/None value.
+        :param my_instance: Instance to use.
+        :return: Return the class name of my_instance, or "Instance.None" in case of error/None value.
         """
-        if myInstance is None:
+        if my_instance is None:
             return "Instance.None"
         else:
-            return myInstance.__class__.__name__
+            return my_instance.__class__.__name__
 
     @classmethod
-    def getPathSeparator(cls):
+    def get_pathseparator(cls):
         """
         Return the path separator.
         http://docs.python.org/library/os.html#os.sep
@@ -551,67 +551,65 @@ class SolBase(object):
         return os.sep
 
     @classmethod
-    def isString(cls, myString):
+    def is_string(cls, my_string):
         """
-        Return true if the provided myString is a str or an unicode.
+        Return true if the provided my_string is a str or an unicode.
         :param cls: Our class.
-        :param myString: A String.
-        :return: Return true if the provided myString is a str or an unicode. False otherwise.
+        :param my_string: A String.
+        :return: Return true if the provided my_string is a str or an unicode. False otherwise.
         """
-        if myString is None:
+        if my_string is None:
             return False
         else:
-            return isinstance(myString, (str, unicode))
+            return isinstance(my_string, (str, unicode))
 
     @classmethod
-    def isStringNotEmpty(cls, myString):
+    def is_string_not_empty(cls, my_string):
         """
-        Return true if the provided myString is a str or an unicode, not empty.
+        Return true if the provided my_string is a str or an unicode, not empty.
         :param cls: Our class.
-        :param myString: A String.
-        :return: Return true if the provided myString is a str or an unicode, not empty.. False otherwise.
+        :param my_string: A String.
+        :return: Return true if the provided my_string is a str or an unicode, not empty.. False otherwise.
         """
-        if not SolBase.isString(myString):
+        if not SolBase.is_string(my_string):
             return False
         else:
-            return len(myString) > 0
+            return len(my_string) > 0
 
     @classmethod
-    def isBoolean(cls, myBool):
+    def is_bool(cls, my_bool):
         """
-        Return true if the provided myBool is a boolean.
+        Return true if the provided my_bool is a boolean.
         :param cls: Our class.
-        :param myBool: A boolean..
-        :return: Return true if the provided myBool is a boolean. False otherwise.
+        :param my_bool: A boolean..
+        :return: Return true if the provided my_bool is a boolean. False otherwise.
         """
-        if myBool is None:
+        if my_bool is None:
             return False
         else:
-            return isinstance(myBool, bool)
+            return isinstance(my_bool, bool)
 
     @classmethod
-    def isInteger(cls, myInt):
+    def is_int(cls, my_int):
         """
-        Return true if the provided myInt is a integer.
+        Return true if the provided my_int is a integer.
         :param cls: Our class.
-        :param myInt: An integer..
-        :return: Return true if the provided myInt is a integer. False otherwise.
+        :param my_int: An integer..
+        :return: Return true if the provided my_int is a integer. False otherwise.
         """
-        if myInt is None:
+        if my_int is None:
             return False
         # Caution, boolean is an integer...
-        elif SolBase.isBoolean(myInt):
+        elif SolBase.is_bool(my_int):
             return False
         else:
-            return isinstance(myInt, (int, long))
+            return isinstance(my_int, (int, long))
 
     @classmethod
-    def getCurrentPidsAsString(cls):
+    def get_current_pid_as_string(cls):
         """
         Return the current pids as string.
         :param cls: Our class.
         :return: A String
         """
-        return "pid={0}, ppid={1}".format(os.getpid(), os.getppid())
-
-
+        return "pid={0}, ppid={1}".format(os.getpid(), os.getppid())
\ No newline at end of file
